@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Inline;
 
 our $DATE = '2015-05-25'; # DATE
-our $VERSION = '0.01'; # VERSION
+our $VERSION = '0.02'; # VERSION
 
 use 5.010001;
 use strict;
@@ -559,7 +559,8 @@ _
 
         # embed Data::Check::Structure 0.03
         $cd->{embedded_packages}{'Data::Check::Structure'} = <<'_';
-package Data::Check::Structure;
+package
+    Data::Check::Structure; # avoid PAUSE indexing
 
 our $DATE = '2014-07-14'; # DATE
 our $VERSION = '0.03'; # VERSION
@@ -724,7 +725,8 @@ _
 
         # embed Text::Table::Tiny 0.03
         $cd->{embedded_packages}{'Text::Table::Tiny'} = <<'_';
-package Text::Table::Tiny;
+package
+    Text::Table::Tiny; # avoid PAUSE indexer
 use List::Util qw();
 
 our $COLUMN_SEPARATOR = '|';
@@ -901,7 +903,7 @@ Perinci::CmdLine::Inline - Generate inline Perinci::CmdLine CLI script
 
 =head1 VERSION
 
-This document describes version 0.01 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2015-05-25.
+This document describes version 0.02 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2015-05-25.
 
 =head1 SYNOPSIS
 
